%global __requires_exclude perl

Summary:	Fast anti-spam filtering by Bayesian statistical analysis
Name:		bogofilter
Version:	1.2.5
Release:	%mkrel 1
License:	GPLv2+
Group:		Networking/Mail
URL:		http://bogofilter.sourceforge.net
Source0:	http://prdownloads.sourceforge.net/bogofilter/%{name}-%{version}.tar.xz
BuildRequires:	db-devel
BuildRequires:	pkgconfig(gsl)
BuildRequires:	valgrind
BuildRequires:	flex
BuildRequires:	openjade

%description
Bogofilter is a Bayesian spam filter. In its normal mode of
operation, it takes an email message or other text on standard
input, does a statistical check against lists of "good" and
"bad" words, and returns a status code indicating whether or not
the message is spam. Bogofilter is designed with fast algorithms
(including Berkeley DB system), coded directly in C, and tuned for
speed, so it can be used for production by sites that process a
lot of mail.

%prep
%setup -q

%build

%configure \
    --disable-rpath \
    --disable-transactions \
    --with-database=db \
    --disable-dependency-tracking \
    --without-included-gsl

%make_build

%ifnarch armv7hl
# Some strange test failures that would need to be investigated but don't seem fatal
# 3/54 Failed:
#./outputs/dump.load-2.out ./checks.23370.20160529T004141/dump.load-2.txt differ: char 87, line 3
#FAIL: t.dump.load
#want: "7.2 6.20030303 10.20030304", have: "1.2 6.20030303 10.20030304"
#FAIL: t.nonascii.replace
#./outputs/bulkmode.out ./checks.24400.20160529T004148/bulk-double-2.out differ: char 80, line 3
#FAIL: t.bulkmode
%check
make DESTDIR="%{buildroot}" check
%endif

%install
%make_install

mv %{buildroot}%{_sysconfdir}/bogofilter.cf.example %{buildroot}%{_sysconfdir}/bogofilter.cf

# trio is embedded and has different AUTHORS, CHANGES, README
mkdir -p %{buildroot}%{_datadir}/doc/%{name}/trio
%__cp trio/CHANGES %{buildroot}%{_datadir}/doc/%{name}/trio/CHANGES
%__cp trio/AUTHORS %{buildroot}%{_datadir}/doc/%{name}/trio/AUTHORS
%__cp trio/README %{buildroot}%{_datadir}/doc/%{name}/trio/README

##include contrib, some may find it useful
for d in contrib ; do
  install -d %{buildroot}%{_datadir}/%{name}/$d
  files=$(find "$d" -maxdepth 1 -type f -print)
  for f in $files ; do
    case $f in
      *.c|*.o|*.obj|*/Makefile*) continue ;;
      *.1)
    cp -p $f %{buildroot}%{_mandir}/man1 ;;
      *)
    cp -p $f %{buildroot}%{_datadir}/%{name}/$d ;;
    esac
  done
done

%files
%doc AUTHORS GETTING.STARTED Doxyfile NEWS
%doc README* OBITUARY TODO RELEASE.NOTES*
%doc bogofilter.cf.example
%doc doc/README* doc/bogofilter-SA*
%doc doc/integrating-* doc/*.html doc/*.xml
%doc contrib/README*
%doc %{_datadir}/doc/%{name}/trio
%config(noreplace) %{_sysconfdir}/bogofilter.cf
%{_bindir}/*
%{_datadir}/bogofilter
%{_mandir}/man1/*


%changelog
* Sat Apr 18 2020 julien <julien> 1.2.5-1.mga8
+ Revision: 1569329
- new version 1.2.5
- spellcheck
- properly add doc for embedded trio
- simplify install of html/xml doc

* Sun Feb 16 2020 umeabot <umeabot> 1.2.4-10.mga8
+ Revision: 1529681
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Aug 27 2019 daviddavid <daviddavid> 1.2.4-9.mga8
+ Revision: 1433724
- rebuild for new gsl 2.6

* Fri Sep 21 2018 umeabot <umeabot> 1.2.4-8.mga7
+ Revision: 1295586
- Mageia 7 Mass Rebuild

* Wed Dec 27 2017 wally <wally> 1.2.4-7.mga7
+ Revision: 1185638
- rebuild for new gsl

* Tue Jun 28 2016 pterjan <pterjan> 1.2.4-6.mga6
+ Revision: 1038002
- Disable tests on armv7hl

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.2.4-5.mga6
+ Revision: 918998
- rebuild for gsl

* Wed Oct 15 2014 umeabot <umeabot> 1.2.4-4.mga5
+ Revision: 749287
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.4-3.mga5
+ Revision: 678191
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Mon Oct 21 2013 umeabot <umeabot> 1.2.4-2.mga4
+ Revision: 539496
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 julien <julien> 1.2.4-1.mga4
+ Revision: 492338
- new version 1.2.4

* Fri Jan 11 2013 umeabot <umeabot> 1.2.3-2.mga3
+ Revision: 346936
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 06 2012 julien <julien> 1.2.3-1.mga3
+ Revision: 327545
- new version 1.2.3

* Tue Jul 31 2012 fwang <fwang> 1.2.2-4.mga3
+ Revision: 276366
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 1.2.2-3.mga3
+ Revision: 274763
- build with system db

* Fri Feb 25 2011 ahmad <ahmad> 1.2.2-2.mga1
+ Revision: 59198
- imported package bogofilter

